@@ -11,7 +11,7 @@ val.rose <- function(x)
                 length(x@circle),", but must be 1!\n",sep=""))
     if (sum(is.na(x@cyclVar))>0)
       return("slot 'cyclVar' must not contain NAs!\n")
-    if (min(x@cyclVar,rm.na=T)<0 || max(x@cyclVar,rm.na=T)>=x@circle)
+    if (min(x@cyclVar,rm.na=TRUE)<0 || max(x@cyclVar,rm.na=T)>=x@circle)
       return("The following condition must be valid: 0 <= 'cyclVar' < 'circle'!\n")
     if (!any(sort(x@cyclVar)==x@cyclVar))
       return("'cyclVar' must be sorted by increasing values!\n")
